

%  This simple example shows how to do basic rendering and pipeline
%  creation.

vtk_init;
%  The colors module defines various useful colors.


%  This creates a polygonal cylinder model with eight circumferential
%  facets.
cylinder = vtkCylinderSource();
cylinder.SetResolution(8);

%  The mapper is responsible for pushing the geometry into the graphics
%  library. It may also do color mapping, if scalars or other
%  attributes are defined.
cylinderMapper = vtkPolyDataMapper();
cylinderMapper.SetInput(cylinder.GetOutput());

%  The actor is a grouping mechanism: besides the geometry (mapper), it
%  also has a property, transformation matrix, and/or texture map.
%  Here we set its color and rotate it -22.5 degrees.
cylinderActor = vtkActor();
cylinderActor.SetMapper(cylinderMapper);
cylinderActor.GetProperty().SetColor(0.9,0,0);
cylinderActor.RotateX(30.0);
cylinderActor.RotateY(-45.0);

%  Create the graphics structure. The renderer renders into the render
%  window. The render window interactor captures mouse events and will
%  perform appropriate camera or actor manipulation depending on the
%  nature of the events.
ren = vtkRenderer();
renWin = vtkRenderWindow();
renWin.AddRenderer(ren);
iren = vtkRenderWindowInteractor();
iren.SetRenderWindow(renWin);

%  Add the actors to the renderer, set the background and size
ren.AddActor(cylinderActor);
ren.SetBackground(0.1, 0.2, 0.4);
renWin.SetSize(200, 200);

%  This allows the interactor to initalize itself. It has to be
%  called before an event loop. 


%  We'll zoom in a little by accessing the camera and invoking a "Zoom"
%  method on it.
ren.GetActiveCamera().Zoom(1.5);
% renWin.Render();

%  Start the event loop.
vtkInitializeInteractor(iren);
